PhoenixKitDocumentCreator.Web.DocumentsLive (PhoenixKitDocumentCreator v0.2.6)

Copy Markdown View Source

Main listing page for the Document Creator.

Lists templates and documents from the local database for fast rendering. Background sync keeps the DB in sync with Google Drive. Files that disappear from Drive are shown with a "lost" indicator.